@@ -1,4 +1,6 @@
 import json
+
+from spackle import SpackleException
 from spackle.stores.base import Store
 
 
@@ -7,9 +9,16 @@ class FileStore(Store):
         self.path = path
 
     def get_customer_data(self, customer_id):
-        with open(self.path, "r") as f:
-            data = json.load(f)
-        return data.get(customer_id)
+        try:
+            with open(self.path, "r") as f:
+                data = json.load(f)
+        except (FileNotFoundError, json.decoder.JSONDecodeError):
+            data = {}
+
+        try:
+            return data[customer_id]
+        except KeyError:
+            raise SpackleException("Customer %s not found" % customer_id)
 
     def set_customer_data(self, customer_id, customer_data):
         try:
@@ -20,4 +29,4 @@ class FileStore(Store):
 
         data[customer_id] = customer_data
         with open(self.path, "w") as f:
-            f.write(json.dumps(data))
\ No newline at end of file
+            f.write(json.dumps(data))
