@@ -1,3 +1,4 @@
+from spackle import SpackleException
 from spackle.stores.base import Store
 
 
@@ -6,7 +7,10 @@ class MemoryStore(Store):
         self.data = {}
 
     def get_customer_data(self, customer_id):
-        return self.data.get(customer_id, None)
+        try:
+            return self.data[customer_id]
+        except KeyError:
+            raise SpackleException("Customer %s not found" % customer_id)
 
     def set_customer_data(self, customer_id, data):
         self.data[customer_id] = data
